***********************************
Library reference guide
***********************************

This chapter provides documentation for the different methods and classes defined in the main Python module ANNarchy. For an easier usage, ANNarchy uses an object oriented approach to represent the neural network. After defining `neurons <API/Neuron.html>`_ and `Synapses <API/Synapse.html>`_, the user build up his network consisting of `populations <API/Population.html>`_ interconnected by `projections <API/Projection.html>`_.

.. toctree::
    :maxdepth: 3

    API/ANNarchy.rst
    API/Neuron.rst
    API/SpecificNeuron.rst
    API/Synapse.rst
    API/SpecificSynapse.rst
    API/Population.rst
    API/SpecificPopulation.rst
    API/SpecificProjection.rst
    API/Projections.rst
    API/Dendrite.rst
    API/Monitor.rst
    API/RandomDistribution.rst
    API/Network.rst
    API/IO.rst
    API/Utilities.rst
    API/Hybrid.rst
    API/Convolution.rst
    API/Logging.rst
